mock

package
v1.67.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2022 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package mock is a generated GoMock package.

Package mock is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockMessage

type MockMessage struct {
	// contains filtered or unexported fields
}

MockMessage is a mock of Message interface

func NewMockMessage

func NewMockMessage(ctrl *gomock.Controller) *MockMessage

NewMockMessage creates a new mock instance

func (*MockMessage) EXPECT

func (m *MockMessage) EXPECT() *MockMessageMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockMessage) GetContent

func (m *MockMessage) GetContent() string

GetContent mocks base method

type MockMessageMockRecorder

type MockMessageMockRecorder struct {
	// contains filtered or unexported fields
}

MockMessageMockRecorder is the mock recorder for MockMessage

func (*MockMessageMockRecorder) GetContent

func (mr *MockMessageMockRecorder) GetContent() *gomock.Call

GetContent indicates an expected call of GetContent

type MockNotificationProvider

type MockNotificationProvider struct {
	// contains filtered or unexported fields
}

MockNotificationProvider is a mock of NotificationProvider interface

func NewMockNotificationProvider

func NewMockNotificationProvider(ctrl *gomock.Controller) *MockNotificationProvider

NewMockNotificationProvider creates a new mock instance

func (*MockNotificationProvider) CanHandleMessage

func (m *MockNotificationProvider) CanHandleMessage() bool

CanHandleMessage mocks base method

func (*MockNotificationProvider) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockNotificationProvider) HandleMessage

func (m *MockNotificationProvider) HandleMessage() error

HandleMessage mocks base method

type MockNotificationProviderMockRecorder

type MockNotificationProviderMockRecorder struct {
	// contains filtered or unexported fields
}

MockNotificationProviderMockRecorder is the mock recorder for MockNotificationProvider

func (*MockNotificationProviderMockRecorder) CanHandleMessage

func (mr *MockNotificationProviderMockRecorder) CanHandleMessage() *gomock.Call

CanHandleMessage indicates an expected call of CanHandleMessage

func (*MockNotificationProviderMockRecorder) HandleMessage

func (mr *MockNotificationProviderMockRecorder) HandleMessage() *gomock.Call

HandleMessage indicates an expected call of HandleMessage

Jump to