package
Version:
v1.56.14
Opens a new window with list of versions in this module.
Published: Dec 1, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func AdaptFunc(
monitor mntr.Monitor,
namespace string,
publicServiceNameLabels *labels.Name,
privateServiceNameLabels *labels.Name,
cockroachSelector *labels.Selector,
cockroachPort int32,
cockroachHTTPPort int32,
) (
operator.QueryFunc,
operator.DestroyFunc,
error,
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.